@@ -1,15 +1,15 @@
-#! /usr/bin/python
+#! /usr/bin/python3
 ##############################################################################
 ## 
 #  \file __init__.py
 #  \brief IAPACK initialization script.
-#  \version 0.4
+#  \version 0.5
 #  \author Dimitri Denk
-#  \date 19.11.2011
+#  \date 27.07.2021
 #
 #  This script initializes the IAPACK
 #
-#  Copyright (c) 2010-2011
+#  Copyright (c) 2010-2021
 #  DENKTECH
 #  www.denktech.de
 #
@@ -21,15 +21,21 @@
 #  the suitability of this software for any purpose. 
 #  It is provided "as is" without express or implied warranty.
 #
+#  History:
+#  19.11.2011 DD release 0.4
+#  27.07.2021 DD reworking of interface for Python3
+#
 #############################################################################
 
-__all__ = ["phase", "calibrate", "zernike", "utils", "reports"]
+from .phase import get_frame, get_phase, get_phase_dev, calc_phase, unwrap_phase
+from .calibrate import calibrate
+from .zernike import zernike_coefficients, fast_zernike_coefficients, synthetic_surface
+from .utils import save_csv, save_txt, smooth
+# from .reports import make_pdf_report
+from .simdev import DTISIM
+from .dti3 import DTI3
 
-from phase import get_frame, get_phase, get_phase_dev, calc_phase, unwrap_phase
-from calibrate import calibrate
-from zernike import zernike_coefficients, fast_zernike_coefficients, synthetic_surface
-from utils import save_csv, save_txt, smooth
-from reports import make_pdf_report
- 
 from numpy import save, load
 
+# EOF
+
